@@ -15,7 +15,7 @@ class FunctionDeployer:
         self.is_delete = is_delete
         self.is_pr = pr
         self.deployment = deployment
-        self.client_api_key = project_info.get_client_api_key()
+        self.oidc = project_info.oidc
         self.secrets = (
             {}
             if (self.is_delete or self.deployment.secret_names is None)
@@ -44,8 +44,8 @@ class FunctionDeployer:
             self.function_name,
             file_id,
             self.secrets,
-            self.client_api_key,
             owner="AIR",
+            oidc=self.oidc,
         )
 
     def handle_push(self) -> None:
@@ -60,7 +60,7 @@ class FunctionDeployer:
             self.function_name_latest,
             file_id,
             self.secrets,
-            self.client_api_key,
             owner="AIR",
+            oidc=self.oidc,
         )
         functions.delete_function(self.client, self.function_name)
