@@ -41,8 +41,8 @@ def deploy_function(
     function_name: str,
     file_id: int,
     secrets: Dict[str, str],
-    api_key: str,
     owner: str = "",
+    oidc: bool = True,
 ) -> None:
     delete_function_if_exists(client, function_name)
     secrets = format_secret_names(secrets)
@@ -61,7 +61,7 @@ def deploy_function(
                 file_id=file_id,
                 secrets=secrets,
                 external_id=function_name,
-                api_key=api_key,
+                api_key=client._config.api_key if not oidc else None,
                 owner=owner,
             )
             success = cdf.await_function_deployment(client, function_name, 900)
